trouble-host

Crates

0.6.0

Versions

default

Flavors

NotAllowedEvent

Struct NotAllowedEvent 

pub struct NotAllowedEvent<'stack, 'server, P: PacketPool> { /* private fields */ }
Other event returned while processing GATT requests (neither read, nor write).

Implementations

Source

impl<'stack, P: PacketPool> NotAllowedEvent<'stack, '_, P>

pub fn handle(&self) -> u16

Characteristic handle that was requested

pub fn accept(self) -> Result<Reply<'stack, P>, Error>

Accept the event, making it processed by the server.

Automatically called if drop() is invoked.

pub fn reject(self, err: AttErrorCode) -> Result<Reply<'stack, P>, Error>

Reject the event with the provided error code, it will not be processed by the attribute server.

pub fn payload(&self) -> &GattData<'stack, P>

Get a reference to the underlying GattData payload that this event is enclosing

pub fn into_payload(self) -> GattData<'stack, P>

Convert the event back into the GattData payload it is enclosing

Allows for custom processing of the enclosed data, as in handling payloads which are not supported yet by the enclosed attribute server. Note that this will consume the event, so it would be up to the caller to respond to the incoming payload if needed and however they see fit.